==============
latticeadaptor
==============

.. image:: https://readthedocs.org/projects/latticeadaptor/badge/
    :alt: Documentation Status
    :scale: 100%
    :target: http://latticeadaptor.readthedocs.io


.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/tomerten/latticeadaptor/main?filepath=docs%2Fnotebook%2FTutorial.ipynb


This package is used to convert a table of accelerator lattice elements and their arguments 
to various accelerator lattice formats. Currently covered are:

- MadX (Sequence and Line format)
- Elegant
- Tracy

* Free software: MIT license
* Documentation: https://latticeadaptor.readthedocs.io.


Features
--------

* Fast lattice comparison by plotting element locations against eachother.
* Fast settings compare by comparing magnet settings.
* Quick twiss plotting.
* Quick lattice element plotting.
* Conversion from table to standard formats.

Tutorial on Binder
------------------

https://mybinder.org/v2/gh/tomerten/latticeadaptor/main?filepath=docs%2Fnotebook%2FTutorial.ipynb

